Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/netflix_open_content_helper/__init__.py | (no function) | 10 | 1 | 0 | 90%
src/netflix_open_content_helper/__main__.py | (no function) | 4 | 4 | 0 | 0%
src/netflix_open_content_helper/cli.py | download_from_s3 | 4 | 0 | 0 | 100%
src/netflix_open_content_helper/cli.py | version_callback | 3 | 0 | 0 | 100%
src/netflix_open_content_helper/cli.py | common | 1 | 0 | 0 | 100%
src/netflix_open_content_helper/cli.py | browse | 6 | 0 | 0 | 100%
src/netflix_open_content_helper/cli.py | download | 44 | 4 | 0 | 91%
src/netflix_open_content_helper/cli.py | list_assets | 9 | 0 | 0 | 100%
src/netflix_open_content_helper/cli.py | (no function) | 20 | 1 | 0 | 95%
Total |  | 101 | 10 | 0 | 90%

No items found using the specified filter.